@@ -61,7 +61,7 @@ def home():
         s.loads(token, salt='test_sample_token', max_age=100)
     except SignatureExpired:
         return '<h1>Link is expired!</h1>'
-    if not EvalCandidates.objects(token=token)[0].answer_1:
+    if EvalCandidates.objects(token=token)[0].answer_1:
         return '<h1>Answers already Submitted!</h1>'
 
     visible = True
